==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="58"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 外掛</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="191"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="192"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="193"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 外掛</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="55"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="186"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="187"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="188"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="89"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="90"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="91"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
